# KoGaMa.py-Rewrite

[![Python Version](https://img.shields.io/badge/python-%E2%89%A53.8-yellow.svg)](https://www.python.org/downloads/)  [![Pypi](https://img.shields.io/pypi/v/KoGaMa.py-Rewrite)](https://pypi.org/project/KoGaMa.py-Rewrite/)  ![MIT license](https://img.shields.io/badge/License-MIT-blue.svg)  [![Downloads](https://static.pepy.tech/badge/KoGaMa.py-Rewrite)](https://static.pepy.tech/badge/KoGaMa.py-Rewrite)  

**KoGaMa.py-Rewrite is an API-Wrapper for the KoGaMa Website API. You can create any projects you want with this package.**

About
------

* Original repo made by: Ars3ne --> [KoGaMa.py](https://github.com/Ars3ne/kogama.py)

* Remember to follow [KoGaMa's Terms of Use](https://www.kogama.com/help/terms-and-conditions/) while using this package.


Installation
-------------

Notice: **Python 3.9.x or higher is required.**

```
    # Linux/macOS
    python3 -m pip install KoGaMa.py-Rewrite

    # Windows
    py -3 -m pip install KoGaMa.py-Rewrite
```

Key Features
-------------

- Easy to Use & Learn.
- Many features.

Quick Example
--------------

```python
from Kogama.kogama import KoGaMa

client = KoGaMa("www")
client.login("CoolKoGaMian", "MySecretPassword")
client.post_feed_message("12345678", "hello")
```

Credits
--------
- Tokeeto :: Fixing bugs and for the pull request.

Link
------
- Official Documentation: <https://thenoobpro44.gitbook.io/kogama-py-rewrite/>

* Need any help regarding the package? Contact me on Discord: **TheNoobPro44#5561**
